# coding: utf-8
import pprint
import six
from enum import Enum



class ShopifySubscriptionCreationRequest:

    swagger_types = {
    
        'billing_address': 'ShopifySubscriptionAddressCreate',
        'billing_configuration': 'ShopifySubscriptionModelBillingConfiguration',
        'currency': 'str',
        'external_id': 'str',
        'initial_execution_date': 'datetime',
        'integration': 'int',
        'items': 'list[ShopifySubscriptionModelItem]',
        'language': 'str',
        'shipping_address': 'ShopifySubscriptionAddressCreate',
        'shipping_method_name': 'str',
        'space_view_id': 'int',
        'store_order_confirmation_email_enabled': 'bool',
        'subscriber': 'ShopifySubscriberCreation',
        'subscriber_suspension_allowed': 'bool',
    }

    attribute_map = {
        'billing_address': 'billingAddress','billing_configuration': 'billingConfiguration','currency': 'currency','external_id': 'externalId','initial_execution_date': 'initialExecutionDate','integration': 'integration','items': 'items','language': 'language','shipping_address': 'shippingAddress','shipping_method_name': 'shippingMethodName','space_view_id': 'spaceViewId','store_order_confirmation_email_enabled': 'storeOrderConfirmationEmailEnabled','subscriber': 'subscriber','subscriber_suspension_allowed': 'subscriberSuspensionAllowed',
    }

    
    _billing_address = None
    _billing_configuration = None
    _currency = None
    _external_id = None
    _initial_execution_date = None
    _integration = None
    _items = None
    _language = None
    _shipping_address = None
    _shipping_method_name = None
    _space_view_id = None
    _store_order_confirmation_email_enabled = None
    _subscriber = None
    _subscriber_suspension_allowed = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.billing_address = kwargs.get('billing_address')

        self.billing_configuration = kwargs.get('billing_configuration', None)
        self.currency = kwargs.get('currency')

        self.external_id = kwargs.get('external_id')

        self.initial_execution_date = kwargs.get('initial_execution_date', None)
        self.integration = kwargs.get('integration')

        self.items = kwargs.get('items')

        self.language = kwargs.get('language')

        self.shipping_address = kwargs.get('shipping_address')

        self.shipping_method_name = kwargs.get('shipping_method_name', None)
        self.space_view_id = kwargs.get('space_view_id', None)
        self.store_order_confirmation_email_enabled = kwargs.get('store_order_confirmation_email_enabled', None)
        self.subscriber = kwargs.get('subscriber')

        self.subscriber_suspension_allowed = kwargs.get('subscriber_suspension_allowed', None)
        

    
    @property
    def billing_address(self):
        """Gets the billing_address of this ShopifySubscriptionCreationRequest.

            

        :return: The billing_address of this ShopifySubscriptionCreationRequest.
        :rtype: ShopifySubscriptionAddressCreate
        """
        return self._billing_address

    @billing_address.setter
    def billing_address(self, billing_address):
        """Sets the billing_address of this ShopifySubscriptionCreationRequest.

            

        :param billing_address: The billing_address of this ShopifySubscriptionCreationRequest.
        :type: ShopifySubscriptionAddressCreate
        """
        if billing_address is None:
            raise ValueError("Invalid value for `billing_address`, must not be `None`")

        self._billing_address = billing_address
    
    @property
    def billing_configuration(self):
        """Gets the billing_configuration of this ShopifySubscriptionCreationRequest.

            

        :return: The billing_configuration of this ShopifySubscriptionCreationRequest.
        :rtype: ShopifySubscriptionModelBillingConfiguration
        """
        return self._billing_configuration

    @billing_configuration.setter
    def billing_configuration(self, billing_configuration):
        """Sets the billing_configuration of this ShopifySubscriptionCreationRequest.

            

        :param billing_configuration: The billing_configuration of this ShopifySubscriptionCreationRequest.
        :type: ShopifySubscriptionModelBillingConfiguration
        """

        self._billing_configuration = billing_configuration
    
    @property
    def currency(self):
        """Gets the currency of this ShopifySubscriptionCreationRequest.

            

        :return: The currency of this ShopifySubscriptionCreationRequest.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this ShopifySubscriptionCreationRequest.

            

        :param currency: The currency of this ShopifySubscriptionCreationRequest.
        :type: str
        """
        if currency is None:
            raise ValueError("Invalid value for `currency`, must not be `None`")

        self._currency = currency
    
    @property
    def external_id(self):
        """Gets the external_id of this ShopifySubscriptionCreationRequest.

            A client generated nonce which identifies the entity to be created. Subsequent creation requests with the same external ID will not create new entities but return the initially created entity instead.

        :return: The external_id of this ShopifySubscriptionCreationRequest.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this ShopifySubscriptionCreationRequest.

            A client generated nonce which identifies the entity to be created. Subsequent creation requests with the same external ID will not create new entities but return the initially created entity instead.

        :param external_id: The external_id of this ShopifySubscriptionCreationRequest.
        :type: str
        """
        if external_id is None:
            raise ValueError("Invalid value for `external_id`, must not be `None`")

        self._external_id = external_id
    
    @property
    def initial_execution_date(self):
        """Gets the initial_execution_date of this ShopifySubscriptionCreationRequest.

            

        :return: The initial_execution_date of this ShopifySubscriptionCreationRequest.
        :rtype: datetime
        """
        return self._initial_execution_date

    @initial_execution_date.setter
    def initial_execution_date(self, initial_execution_date):
        """Sets the initial_execution_date of this ShopifySubscriptionCreationRequest.

            

        :param initial_execution_date: The initial_execution_date of this ShopifySubscriptionCreationRequest.
        :type: datetime
        """

        self._initial_execution_date = initial_execution_date
    
    @property
    def integration(self):
        """Gets the integration of this ShopifySubscriptionCreationRequest.

            

        :return: The integration of this ShopifySubscriptionCreationRequest.
        :rtype: int
        """
        return self._integration

    @integration.setter
    def integration(self, integration):
        """Sets the integration of this ShopifySubscriptionCreationRequest.

            

        :param integration: The integration of this ShopifySubscriptionCreationRequest.
        :type: int
        """
        if integration is None:
            raise ValueError("Invalid value for `integration`, must not be `None`")

        self._integration = integration
    
    @property
    def items(self):
        """Gets the items of this ShopifySubscriptionCreationRequest.

            

        :return: The items of this ShopifySubscriptionCreationRequest.
        :rtype: list[ShopifySubscriptionModelItem]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this ShopifySubscriptionCreationRequest.

            

        :param items: The items of this ShopifySubscriptionCreationRequest.
        :type: list[ShopifySubscriptionModelItem]
        """
        if items is None:
            raise ValueError("Invalid value for `items`, must not be `None`")

        self._items = items
    
    @property
    def language(self):
        """Gets the language of this ShopifySubscriptionCreationRequest.

            

        :return: The language of this ShopifySubscriptionCreationRequest.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this ShopifySubscriptionCreationRequest.

            

        :param language: The language of this ShopifySubscriptionCreationRequest.
        :type: str
        """
        if language is None:
            raise ValueError("Invalid value for `language`, must not be `None`")

        self._language = language
    
    @property
    def shipping_address(self):
        """Gets the shipping_address of this ShopifySubscriptionCreationRequest.

            

        :return: The shipping_address of this ShopifySubscriptionCreationRequest.
        :rtype: ShopifySubscriptionAddressCreate
        """
        return self._shipping_address

    @shipping_address.setter
    def shipping_address(self, shipping_address):
        """Sets the shipping_address of this ShopifySubscriptionCreationRequest.

            

        :param shipping_address: The shipping_address of this ShopifySubscriptionCreationRequest.
        :type: ShopifySubscriptionAddressCreate
        """
        if shipping_address is None:
            raise ValueError("Invalid value for `shipping_address`, must not be `None`")

        self._shipping_address = shipping_address
    
    @property
    def shipping_method_name(self):
        """Gets the shipping_method_name of this ShopifySubscriptionCreationRequest.

            

        :return: The shipping_method_name of this ShopifySubscriptionCreationRequest.
        :rtype: str
        """
        return self._shipping_method_name

    @shipping_method_name.setter
    def shipping_method_name(self, shipping_method_name):
        """Sets the shipping_method_name of this ShopifySubscriptionCreationRequest.

            

        :param shipping_method_name: The shipping_method_name of this ShopifySubscriptionCreationRequest.
        :type: str
        """

        self._shipping_method_name = shipping_method_name
    
    @property
    def space_view_id(self):
        """Gets the space_view_id of this ShopifySubscriptionCreationRequest.

            

        :return: The space_view_id of this ShopifySubscriptionCreationRequest.
        :rtype: int
        """
        return self._space_view_id

    @space_view_id.setter
    def space_view_id(self, space_view_id):
        """Sets the space_view_id of this ShopifySubscriptionCreationRequest.

            

        :param space_view_id: The space_view_id of this ShopifySubscriptionCreationRequest.
        :type: int
        """

        self._space_view_id = space_view_id
    
    @property
    def store_order_confirmation_email_enabled(self):
        """Gets the store_order_confirmation_email_enabled of this ShopifySubscriptionCreationRequest.

            

        :return: The store_order_confirmation_email_enabled of this ShopifySubscriptionCreationRequest.
        :rtype: bool
        """
        return self._store_order_confirmation_email_enabled

    @store_order_confirmation_email_enabled.setter
    def store_order_confirmation_email_enabled(self, store_order_confirmation_email_enabled):
        """Sets the store_order_confirmation_email_enabled of this ShopifySubscriptionCreationRequest.

            

        :param store_order_confirmation_email_enabled: The store_order_confirmation_email_enabled of this ShopifySubscriptionCreationRequest.
        :type: bool
        """

        self._store_order_confirmation_email_enabled = store_order_confirmation_email_enabled
    
    @property
    def subscriber(self):
        """Gets the subscriber of this ShopifySubscriptionCreationRequest.

            

        :return: The subscriber of this ShopifySubscriptionCreationRequest.
        :rtype: ShopifySubscriberCreation
        """
        return self._subscriber

    @subscriber.setter
    def subscriber(self, subscriber):
        """Sets the subscriber of this ShopifySubscriptionCreationRequest.

            

        :param subscriber: The subscriber of this ShopifySubscriptionCreationRequest.
        :type: ShopifySubscriberCreation
        """
        if subscriber is None:
            raise ValueError("Invalid value for `subscriber`, must not be `None`")

        self._subscriber = subscriber
    
    @property
    def subscriber_suspension_allowed(self):
        """Gets the subscriber_suspension_allowed of this ShopifySubscriptionCreationRequest.

            

        :return: The subscriber_suspension_allowed of this ShopifySubscriptionCreationRequest.
        :rtype: bool
        """
        return self._subscriber_suspension_allowed

    @subscriber_suspension_allowed.setter
    def subscriber_suspension_allowed(self, subscriber_suspension_allowed):
        """Sets the subscriber_suspension_allowed of this ShopifySubscriptionCreationRequest.

            

        :param subscriber_suspension_allowed: The subscriber_suspension_allowed of this ShopifySubscriptionCreationRequest.
        :type: bool
        """

        self._subscriber_suspension_allowed = subscriber_suspension_allowed
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ShopifySubscriptionCreationRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ShopifySubscriptionCreationRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8

from __future__ import absolute_import

import six
import re

from wallee.api_client import ApiClient

class SubscriptionServiceApi:

    def __init__(self, configuration):
        self.api_client = ApiClient(configuration=configuration)

    def apply_changes(self, space_id, request, **kwargs):
        """apply changes

        This operation allows to apply changes on a subscription.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.apply_changes(space_id, request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param SubscriptionChangeRequest request:  (required)
        :return: SubscriptionVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        
        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
        if kwargs.get('async_req'):
            return self.apply_changes_with_http_info(space_id, request, **kwargs)
        else:
            (data) = self.apply_changes_with_http_info(space_id, request, **kwargs)
            return data

    def apply_changes_with_http_info(self, space_id, request, **kwargs):
        """apply changes

        This operation allows to apply changes on a subscription.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.apply_changes_with_http_info(space_id, request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param SubscriptionChangeRequest request:  (required)
        :return: SubscriptionVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'request']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method apply_changes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `apply_changes`")
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `apply_changes`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/subscription/applyChanges', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SubscriptionVersion',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('request_timeout'),
            collection_formats=collection_formats)

    def count(self, space_id, **kwargs):
        """Count

        Counts the number of items in the database as restricted by the given filter.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.count(space_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityQueryFilter filter: The filter which restricts the entities which are used to calculate the count.
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        
        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
        if kwargs.get('async_req'):
            return self.count_with_http_info(space_id, **kwargs)
        else:
            (data) = self.count_with_http_info(space_id, **kwargs)
            return data

    def count_with_http_info(self, space_id, **kwargs):
        """Count

        Counts the number of items in the database as restricted by the given filter.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.count_with_http_info(space_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityQueryFilter filter: The filter which restricts the entities which are used to calculate the count.
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'filter']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method count" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `count`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'filter' in params:
            body_params = params['filter']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/subscription/count', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='int',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('request_timeout'),
            collection_formats=collection_formats)

    def create(self, space_id, create_request, **kwargs):
        """Create

        The create operation creates a new subscription and a corresponding subscription version.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.create(space_id, create_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param SubscriptionCreateRequest create_request:  (required)
        :return: SubscriptionVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        
        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
        if kwargs.get('async_req'):
            return self.create_with_http_info(space_id, create_request, **kwargs)
        else:
            (data) = self.create_with_http_info(space_id, create_request, **kwargs)
            return data

    def create_with_http_info(self, space_id, create_request, **kwargs):
        """Create

        The create operation creates a new subscription and a corresponding subscription version.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.create_with_http_info(space_id, create_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param SubscriptionCreateRequest create_request:  (required)
        :return: SubscriptionVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'create_request']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `create`")
        # verify the required parameter 'create_request' is set
        if ('create_request' not in params or
                params['create_request'] is None):
            raise ValueError("Missing the required parameter `create_request` when calling `create`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_request' in params:
            body_params = params['create_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/subscription/create', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SubscriptionVersion',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('request_timeout'),
            collection_formats=collection_formats)

    def initialize(self, space_id, subscription_id, **kwargs):
        """initialize

        The initialize operation initializes a subscription. This method uses charge flows to carry out the transaction.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.initialize(space_id, subscription_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int subscription_id: The provided subscription id will be used to lookup the subscription which should be initialized. (required)
        :return: SubscriptionCharge
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        
        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
        if kwargs.get('async_req'):
            return self.initialize_with_http_info(space_id, subscription_id, **kwargs)
        else:
            (data) = self.initialize_with_http_info(space_id, subscription_id, **kwargs)
            return data

    def initialize_with_http_info(self, space_id, subscription_id, **kwargs):
        """initialize

        The initialize operation initializes a subscription. This method uses charge flows to carry out the transaction.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.initialize_with_http_info(space_id, subscription_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int subscription_id: The provided subscription id will be used to lookup the subscription which should be initialized. (required)
        :return: SubscriptionCharge
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'subscription_id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method initialize" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `initialize`")
        # verify the required parameter 'subscription_id' is set
        if ('subscription_id' not in params or
                params['subscription_id'] is None):
            raise ValueError("Missing the required parameter `subscription_id` when calling `initialize`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'subscription_id' in params:
            query_params.append(('subscriptionId', params['subscription_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/subscription/initialize', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SubscriptionCharge',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('request_timeout'),
            collection_formats=collection_formats)

    def initialize_subscriber_present(self, space_id, subscription_id, **kwargs):
        """initializeSubscriberPresent

        The initialize operation initializes a subscription when the subscriber is present. The method will initialize a transaction which has to be completed by using the transaction service.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.initialize_subscriber_present(space_id, subscription_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int subscription_id:  (required)
        :param str success_url: The subscriber will be redirected to the success URL when the transaction is successful.
        :param str failed_url: The subscriber will be redirected to the fail URL when the transaction fails.
        :return: SubscriptionCharge
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        
        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
        if kwargs.get('async_req'):
            return self.initialize_subscriber_present_with_http_info(space_id, subscription_id, **kwargs)
        else:
            (data) = self.initialize_subscriber_present_with_http_info(space_id, subscription_id, **kwargs)
            return data

    def initialize_subscriber_present_with_http_info(self, space_id, subscription_id, **kwargs):
        """initializeSubscriberPresent

        The initialize operation initializes a subscription when the subscriber is present. The method will initialize a transaction which has to be completed by using the transaction service.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.initialize_subscriber_present_with_http_info(space_id, subscription_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int subscription_id:  (required)
        :param str success_url: The subscriber will be redirected to the success URL when the transaction is successful.
        :param str failed_url: The subscriber will be redirected to the fail URL when the transaction fails.
        :return: SubscriptionCharge
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'subscription_id', 'success_url', 'failed_url']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method initialize_subscriber_present" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `initialize_subscriber_present`")
        # verify the required parameter 'subscription_id' is set
        if ('subscription_id' not in params or
                params['subscription_id'] is None):
            raise ValueError("Missing the required parameter `subscription_id` when calling `initialize_subscriber_present`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'subscription_id' in params:
            query_params.append(('subscriptionId', params['subscription_id']))
        if 'success_url' in params:
            query_params.append(('successUrl', params['success_url']))
        if 'failed_url' in params:
            query_params.append(('failedUrl', params['failed_url']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/subscription/initializeSubscriberPresent', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SubscriptionCharge',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('request_timeout'),
            collection_formats=collection_formats)

    def read(self, space_id, id, **kwargs):
        """Read

        Reads the entity with the given 'id' and returns it.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.read(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the subscription which should be returned. (required)
        :return: Subscription
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        
        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
        if kwargs.get('async_req'):
            return self.read_with_http_info(space_id, id, **kwargs)
        else:
            (data) = self.read_with_http_info(space_id, id, **kwargs)
            return data

    def read_with_http_info(self, space_id, id, **kwargs):
        """Read

        Reads the entity with the given 'id' and returns it.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.read_with_http_info(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the subscription which should be returned. (required)
        :return: Subscription
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method read" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `read`")
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `read`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'id' in params:
            query_params.append(('id', params['id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['*/*'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/subscription/read', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Subscription',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('request_timeout'),
            collection_formats=collection_formats)

    def search(self, space_id, query, **kwargs):
        """Search

        Searches for the entities as specified by the given query.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.search(space_id, query, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityQuery query: The query restricts the subscriptions which are returned by the search. (required)
        :return: list[Subscription]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        
        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
        if kwargs.get('async_req'):
            return self.search_with_http_info(space_id, query, **kwargs)
        else:
            (data) = self.search_with_http_info(space_id, query, **kwargs)
            return data

    def search_with_http_info(self, space_id, query, **kwargs):
        """Search

        Searches for the entities as specified by the given query.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.search_with_http_info(space_id, query, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityQuery query: The query restricts the subscriptions which are returned by the search. (required)
        :return: list[Subscription]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'query']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `search`")
        # verify the required parameter 'query' is set
        if ('query' not in params or
                params['query'] is None):
            raise ValueError("Missing the required parameter `query` when calling `search`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'query' in params:
            body_params = params['query']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/subscription/search', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Subscription]',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('request_timeout'),
            collection_formats=collection_formats)

    def search_subscription_invoices(self, space_id, subscription_id, query, **kwargs):
        """Search Subscription Invoices

        This operation allows to search for subscription invoices.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.search_subscription_invoices(space_id, subscription_id, query, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int subscription_id: The id of the subscription for which the invoices should be searched for. (required)
        :param EntityQuery query: The query restricts the invoices which are returned by the search. (required)
        :return: list[TransactionInvoice]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        
        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
        if kwargs.get('async_req'):
            return self.search_subscription_invoices_with_http_info(space_id, subscription_id, query, **kwargs)
        else:
            (data) = self.search_subscription_invoices_with_http_info(space_id, subscription_id, query, **kwargs)
            return data

    def search_subscription_invoices_with_http_info(self, space_id, subscription_id, query, **kwargs):
        """Search Subscription Invoices

        This operation allows to search for subscription invoices.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.search_subscription_invoices_with_http_info(space_id, subscription_id, query, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int subscription_id: The id of the subscription for which the invoices should be searched for. (required)
        :param EntityQuery query: The query restricts the invoices which are returned by the search. (required)
        :return: list[TransactionInvoice]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'subscription_id', 'query']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search_subscription_invoices" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `search_subscription_invoices`")
        # verify the required parameter 'subscription_id' is set
        if ('subscription_id' not in params or
                params['subscription_id'] is None):
            raise ValueError("Missing the required parameter `subscription_id` when calling `search_subscription_invoices`")
        # verify the required parameter 'query' is set
        if ('query' not in params or
                params['query'] is None):
            raise ValueError("Missing the required parameter `query` when calling `search_subscription_invoices`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'subscription_id' in params:
            query_params.append(('subscriptionId', params['subscription_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'query' in params:
            body_params = params['query']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/subscription/searchSubscriptionInvoices', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TransactionInvoice]',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('request_timeout'),
            collection_formats=collection_formats)

    def terminate(self, space_id, subscription_id, respect_termination_period, **kwargs):
        """terminate

        This operation allows to terminate a subscription.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.terminate(space_id, subscription_id, respect_termination_period, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int subscription_id: The subscription id identifies the subscription which should be terminated. (required)
        :param bool respect_termination_period: The respect termination period controls whether the termination period configured on the product version should be respected or if the operation should take effect immediately. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        
        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
        if kwargs.get('async_req'):
            return self.terminate_with_http_info(space_id, subscription_id, respect_termination_period, **kwargs)
        else:
            (data) = self.terminate_with_http_info(space_id, subscription_id, respect_termination_period, **kwargs)
            return data

    def terminate_with_http_info(self, space_id, subscription_id, respect_termination_period, **kwargs):
        """terminate

        This operation allows to terminate a subscription.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.terminate_with_http_info(space_id, subscription_id, respect_termination_period, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int subscription_id: The subscription id identifies the subscription which should be terminated. (required)
        :param bool respect_termination_period: The respect termination period controls whether the termination period configured on the product version should be respected or if the operation should take effect immediately. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'subscription_id', 'respect_termination_period']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method terminate" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `terminate`")
        # verify the required parameter 'subscription_id' is set
        if ('subscription_id' not in params or
                params['subscription_id'] is None):
            raise ValueError("Missing the required parameter `subscription_id` when calling `terminate`")
        # verify the required parameter 'respect_termination_period' is set
        if ('respect_termination_period' not in params or
                params['respect_termination_period'] is None):
            raise ValueError("Missing the required parameter `respect_termination_period` when calling `terminate`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'subscription_id' in params:
            query_params.append(('subscriptionId', params['subscription_id']))
        if 'respect_termination_period' in params:
            query_params.append(('respectTerminationPeriod', params['respect_termination_period']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/subscription/terminate', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('request_timeout'),
            collection_formats=collection_formats)

    def update(self, space_id, subscription_id, request, **kwargs):
        """update

        This operation allows to update the subscription.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.update(space_id, subscription_id, request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int subscription_id:  (required)
        :param SubscriptionUpdateRequest request:  (required)
        :return: Subscription
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        
        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
        if kwargs.get('async_req'):
            return self.update_with_http_info(space_id, subscription_id, request, **kwargs)
        else:
            (data) = self.update_with_http_info(space_id, subscription_id, request, **kwargs)
            return data

    def update_with_http_info(self, space_id, subscription_id, request, **kwargs):
        """update

        This operation allows to update the subscription.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.update_with_http_info(space_id, subscription_id, request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int subscription_id:  (required)
        :param SubscriptionUpdateRequest request:  (required)
        :return: Subscription
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'subscription_id', 'request']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `update`")
        # verify the required parameter 'subscription_id' is set
        if ('subscription_id' not in params or
                params['subscription_id'] is None):
            raise ValueError("Missing the required parameter `subscription_id` when calling `update`")
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `update`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'subscription_id' in params:
            query_params.append(('subscriptionId', params['subscription_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/subscription/update', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Subscription',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('request_timeout'),
            collection_formats=collection_formats)

    def update_product_version(self, space_id, subscription_id, respect_termination_period, **kwargs):
        """update product version

        The update product version operation updates the product version of the subscription to the latest active product version.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.update_product_version(space_id, subscription_id, respect_termination_period, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int subscription_id: The subscription id identifies the subscription which should be updated to the latest version. (required)
        :param bool respect_termination_period: The subscription version may be retired. The respect termination period controls whether the termination period configured on the product version should be respected or if the operation should take effect immediately. (required)
        :return: SubscriptionVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        
        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
        if kwargs.get('async_req'):
            return self.update_product_version_with_http_info(space_id, subscription_id, respect_termination_period, **kwargs)
        else:
            (data) = self.update_product_version_with_http_info(space_id, subscription_id, respect_termination_period, **kwargs)
            return data

    def update_product_version_with_http_info(self, space_id, subscription_id, respect_termination_period, **kwargs):
        """update product version

        The update product version operation updates the product version of the subscription to the latest active product version.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.update_product_version_with_http_info(space_id, subscription_id, respect_termination_period, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int subscription_id: The subscription id identifies the subscription which should be updated to the latest version. (required)
        :param bool respect_termination_period: The subscription version may be retired. The respect termination period controls whether the termination period configured on the product version should be respected or if the operation should take effect immediately. (required)
        :return: SubscriptionVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'subscription_id', 'respect_termination_period']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_product_version" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `update_product_version`")
        # verify the required parameter 'subscription_id' is set
        if ('subscription_id' not in params or
                params['subscription_id'] is None):
            raise ValueError("Missing the required parameter `subscription_id` when calling `update_product_version`")
        # verify the required parameter 'respect_termination_period' is set
        if ('respect_termination_period' not in params or
                params['respect_termination_period'] is None):
            raise ValueError("Missing the required parameter `respect_termination_period` when calling `update_product_version`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'subscription_id' in params:
            query_params.append(('subscriptionId', params['subscription_id']))
        if 'respect_termination_period' in params:
            query_params.append(('respectTerminationPeriod', params['respect_termination_period']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/subscription/updateProductVersion', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SubscriptionVersion',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8
from enum import Enum, unique


@unique
class RefundType(Enum):
    
    MERCHANT_INITIATED_ONLINE = "MERCHANT_INITIATED_ONLINE"
    MERCHANT_INITIATED_OFFLINE = "MERCHANT_INITIATED_OFFLINE"
    CUSTOMER_INITIATED_AUTOMATIC = "CUSTOMER_INITIATED_AUTOMATIC"
    CUSTOMER_INITIATED_MANUAL = "CUSTOMER_INITIATED_MANUAL"




# coding: utf-8
import pprint
import six
from enum import Enum



class WebAppConfirmationRequest:

    swagger_types = {
    
        'code': 'str',
    }

    attribute_map = {
        'code': 'code',
    }

    
    _code = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.code = kwargs.get('code', None)
        

    
    @property
    def code(self):
        """Gets the code of this WebAppConfirmationRequest.

            The user returns to the web app after granting the permission. The HTTP request contains the code. Provide it here to confirm the web app installation.

        :return: The code of this WebAppConfirmationRequest.
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this WebAppConfirmationRequest.

            The user returns to the web app after granting the permission. The HTTP request contains the code. Provide it here to confirm the web app installation.

        :param code: The code of this WebAppConfirmationRequest.
        :type: str
        """
        if code is not None and len(code) > 100:
            raise ValueError("Invalid value for `code`, length must be less than or equal to `100`")

        self._code = code
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(WebAppConfirmationRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, WebAppConfirmationRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class SubscriptionVersion:

    swagger_types = {
    
        'activated_on': 'datetime',
        'billing_currency': 'str',
        'component_configurations': 'list[SubscriptionComponentConfiguration]',
        'created_on': 'datetime',
        'expected_last_period_end': 'datetime',
        'failed_on': 'datetime',
        'id': 'int',
        'language': 'str',
        'linked_space_id': 'int',
        'planned_purge_date': 'datetime',
        'planned_termination_date': 'datetime',
        'product_version': 'SubscriptionProductVersion',
        'selected_components': 'list[SubscriptionProductComponent]',
        'state': 'SubscriptionVersionState',
        'subscription': 'Subscription',
        'terminated_on': 'datetime',
        'terminating_on': 'datetime',
        'termination_issued_on': 'datetime',
        'version': 'int',
    }

    attribute_map = {
        'activated_on': 'activatedOn','billing_currency': 'billingCurrency','component_configurations': 'componentConfigurations','created_on': 'createdOn','expected_last_period_end': 'expectedLastPeriodEnd','failed_on': 'failedOn','id': 'id','language': 'language','linked_space_id': 'linkedSpaceId','planned_purge_date': 'plannedPurgeDate','planned_termination_date': 'plannedTerminationDate','product_version': 'productVersion','selected_components': 'selectedComponents','state': 'state','subscription': 'subscription','terminated_on': 'terminatedOn','terminating_on': 'terminatingOn','termination_issued_on': 'terminationIssuedOn','version': 'version',
    }

    
    _activated_on = None
    _billing_currency = None
    _component_configurations = None
    _created_on = None
    _expected_last_period_end = None
    _failed_on = None
    _id = None
    _language = None
    _linked_space_id = None
    _planned_purge_date = None
    _planned_termination_date = None
    _product_version = None
    _selected_components = None
    _state = None
    _subscription = None
    _terminated_on = None
    _terminating_on = None
    _termination_issued_on = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.activated_on = kwargs.get('activated_on', None)
        self.billing_currency = kwargs.get('billing_currency', None)
        self.component_configurations = kwargs.get('component_configurations', None)
        self.created_on = kwargs.get('created_on', None)
        self.expected_last_period_end = kwargs.get('expected_last_period_end', None)
        self.failed_on = kwargs.get('failed_on', None)
        self.id = kwargs.get('id', None)
        self.language = kwargs.get('language', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.planned_termination_date = kwargs.get('planned_termination_date', None)
        self.product_version = kwargs.get('product_version', None)
        self.selected_components = kwargs.get('selected_components', None)
        self.state = kwargs.get('state', None)
        self.subscription = kwargs.get('subscription', None)
        self.terminated_on = kwargs.get('terminated_on', None)
        self.terminating_on = kwargs.get('terminating_on', None)
        self.termination_issued_on = kwargs.get('termination_issued_on', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def activated_on(self):
        """Gets the activated_on of this SubscriptionVersion.

            

        :return: The activated_on of this SubscriptionVersion.
        :rtype: datetime
        """
        return self._activated_on

    @activated_on.setter
    def activated_on(self, activated_on):
        """Sets the activated_on of this SubscriptionVersion.

            

        :param activated_on: The activated_on of this SubscriptionVersion.
        :type: datetime
        """

        self._activated_on = activated_on
    
    @property
    def billing_currency(self):
        """Gets the billing_currency of this SubscriptionVersion.

            The subscriber is charged in the billing currency. The billing currency has to be one of the enabled currencies on the subscription product.

        :return: The billing_currency of this SubscriptionVersion.
        :rtype: str
        """
        return self._billing_currency

    @billing_currency.setter
    def billing_currency(self, billing_currency):
        """Sets the billing_currency of this SubscriptionVersion.

            The subscriber is charged in the billing currency. The billing currency has to be one of the enabled currencies on the subscription product.

        :param billing_currency: The billing_currency of this SubscriptionVersion.
        :type: str
        """

        self._billing_currency = billing_currency
    
    @property
    def component_configurations(self):
        """Gets the component_configurations of this SubscriptionVersion.

            

        :return: The component_configurations of this SubscriptionVersion.
        :rtype: list[SubscriptionComponentConfiguration]
        """
        return self._component_configurations

    @component_configurations.setter
    def component_configurations(self, component_configurations):
        """Sets the component_configurations of this SubscriptionVersion.

            

        :param component_configurations: The component_configurations of this SubscriptionVersion.
        :type: list[SubscriptionComponentConfiguration]
        """

        self._component_configurations = component_configurations
    
    @property
    def created_on(self):
        """Gets the created_on of this SubscriptionVersion.

            

        :return: The created_on of this SubscriptionVersion.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this SubscriptionVersion.

            

        :param created_on: The created_on of this SubscriptionVersion.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def expected_last_period_end(self):
        """Gets the expected_last_period_end of this SubscriptionVersion.

            The expected last period end is the date on which the projected end date of the last period is. This is only a projection and as such the actual date may be different.

        :return: The expected_last_period_end of this SubscriptionVersion.
        :rtype: datetime
        """
        return self._expected_last_period_end

    @expected_last_period_end.setter
    def expected_last_period_end(self, expected_last_period_end):
        """Sets the expected_last_period_end of this SubscriptionVersion.

            The expected last period end is the date on which the projected end date of the last period is. This is only a projection and as such the actual date may be different.

        :param expected_last_period_end: The expected_last_period_end of this SubscriptionVersion.
        :type: datetime
        """

        self._expected_last_period_end = expected_last_period_end
    
    @property
    def failed_on(self):
        """Gets the failed_on of this SubscriptionVersion.

            

        :return: The failed_on of this SubscriptionVersion.
        :rtype: datetime
        """
        return self._failed_on

    @failed_on.setter
    def failed_on(self, failed_on):
        """Sets the failed_on of this SubscriptionVersion.

            

        :param failed_on: The failed_on of this SubscriptionVersion.
        :type: datetime
        """

        self._failed_on = failed_on
    
    @property
    def id(self):
        """Gets the id of this SubscriptionVersion.

            A unique identifier for the object.

        :return: The id of this SubscriptionVersion.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SubscriptionVersion.

            A unique identifier for the object.

        :param id: The id of this SubscriptionVersion.
        :type: int
        """

        self._id = id
    
    @property
    def language(self):
        """Gets the language of this SubscriptionVersion.

            The language that is linked to the object.

        :return: The language of this SubscriptionVersion.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this SubscriptionVersion.

            The language that is linked to the object.

        :param language: The language of this SubscriptionVersion.
        :type: str
        """

        self._language = language
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this SubscriptionVersion.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this SubscriptionVersion.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this SubscriptionVersion.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this SubscriptionVersion.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this SubscriptionVersion.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this SubscriptionVersion.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this SubscriptionVersion.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this SubscriptionVersion.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def planned_termination_date(self):
        """Gets the planned_termination_date of this SubscriptionVersion.

            

        :return: The planned_termination_date of this SubscriptionVersion.
        :rtype: datetime
        """
        return self._planned_termination_date

    @planned_termination_date.setter
    def planned_termination_date(self, planned_termination_date):
        """Sets the planned_termination_date of this SubscriptionVersion.

            

        :param planned_termination_date: The planned_termination_date of this SubscriptionVersion.
        :type: datetime
        """

        self._planned_termination_date = planned_termination_date
    
    @property
    def product_version(self):
        """Gets the product_version of this SubscriptionVersion.

            

        :return: The product_version of this SubscriptionVersion.
        :rtype: SubscriptionProductVersion
        """
        return self._product_version

    @product_version.setter
    def product_version(self, product_version):
        """Sets the product_version of this SubscriptionVersion.

            

        :param product_version: The product_version of this SubscriptionVersion.
        :type: SubscriptionProductVersion
        """

        self._product_version = product_version
    
    @property
    def selected_components(self):
        """Gets the selected_components of this SubscriptionVersion.

            

        :return: The selected_components of this SubscriptionVersion.
        :rtype: list[SubscriptionProductComponent]
        """
        return self._selected_components

    @selected_components.setter
    def selected_components(self, selected_components):
        """Sets the selected_components of this SubscriptionVersion.

            

        :param selected_components: The selected_components of this SubscriptionVersion.
        :type: list[SubscriptionProductComponent]
        """

        self._selected_components = selected_components
    
    @property
    def state(self):
        """Gets the state of this SubscriptionVersion.

            The object's current state.

        :return: The state of this SubscriptionVersion.
        :rtype: SubscriptionVersionState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this SubscriptionVersion.

            The object's current state.

        :param state: The state of this SubscriptionVersion.
        :type: SubscriptionVersionState
        """

        self._state = state
    
    @property
    def subscription(self):
        """Gets the subscription of this SubscriptionVersion.

            

        :return: The subscription of this SubscriptionVersion.
        :rtype: Subscription
        """
        return self._subscription

    @subscription.setter
    def subscription(self, subscription):
        """Sets the subscription of this SubscriptionVersion.

            

        :param subscription: The subscription of this SubscriptionVersion.
        :type: Subscription
        """

        self._subscription = subscription
    
    @property
    def terminated_on(self):
        """Gets the terminated_on of this SubscriptionVersion.

            

        :return: The terminated_on of this SubscriptionVersion.
        :rtype: datetime
        """
        return self._terminated_on

    @terminated_on.setter
    def terminated_on(self, terminated_on):
        """Sets the terminated_on of this SubscriptionVersion.

            

        :param terminated_on: The terminated_on of this SubscriptionVersion.
        :type: datetime
        """

        self._terminated_on = terminated_on
    
    @property
    def terminating_on(self):
        """Gets the terminating_on of this SubscriptionVersion.

            

        :return: The terminating_on of this SubscriptionVersion.
        :rtype: datetime
        """
        return self._terminating_on

    @terminating_on.setter
    def terminating_on(self, terminating_on):
        """Sets the terminating_on of this SubscriptionVersion.

            

        :param terminating_on: The terminating_on of this SubscriptionVersion.
        :type: datetime
        """

        self._terminating_on = terminating_on
    
    @property
    def termination_issued_on(self):
        """Gets the termination_issued_on of this SubscriptionVersion.

            

        :return: The termination_issued_on of this SubscriptionVersion.
        :rtype: datetime
        """
        return self._termination_issued_on

    @termination_issued_on.setter
    def termination_issued_on(self, termination_issued_on):
        """Sets the termination_issued_on of this SubscriptionVersion.

            

        :param termination_issued_on: The termination_issued_on of this SubscriptionVersion.
        :type: datetime
        """

        self._termination_issued_on = termination_issued_on
    
    @property
    def version(self):
        """Gets the version of this SubscriptionVersion.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this SubscriptionVersion.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this SubscriptionVersion.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this SubscriptionVersion.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(SubscriptionVersion, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, SubscriptionVersion):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class AnalyticsSchemaTable:

    swagger_types = {
    
        'columns': 'list[AnalyticsSchemaColumn]',
        'description': 'dict(str, str)',
        'table_name': 'str',
    }

    attribute_map = {
        'columns': 'columns','description': 'description','table_name': 'tableName',
    }

    
    _columns = None
    _description = None
    _table_name = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.columns = kwargs.get('columns', None)
        self.description = kwargs.get('description', None)
        self.table_name = kwargs.get('table_name', None)
        

    
    @property
    def columns(self):
        """Gets the columns of this AnalyticsSchemaTable.

            The schemas of all columns of this table.

        :return: The columns of this AnalyticsSchemaTable.
        :rtype: list[AnalyticsSchemaColumn]
        """
        return self._columns

    @columns.setter
    def columns(self, columns):
        """Sets the columns of this AnalyticsSchemaTable.

            The schemas of all columns of this table.

        :param columns: The columns of this AnalyticsSchemaTable.
        :type: list[AnalyticsSchemaColumn]
        """

        self._columns = columns
    
    @property
    def description(self):
        """Gets the description of this AnalyticsSchemaTable.

            A human readable description of the entity type contained in this table.

        :return: The description of this AnalyticsSchemaTable.
        :rtype: dict(str, str)
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AnalyticsSchemaTable.

            A human readable description of the entity type contained in this table.

        :param description: The description of this AnalyticsSchemaTable.
        :type: dict(str, str)
        """

        self._description = description
    
    @property
    def table_name(self):
        """Gets the table_name of this AnalyticsSchemaTable.

            The name of this table.

        :return: The table_name of this AnalyticsSchemaTable.
        :rtype: str
        """
        return self._table_name

    @table_name.setter
    def table_name(self, table_name):
        """Sets the table_name of this AnalyticsSchemaTable.

            The name of this table.

        :param table_name: The table_name of this AnalyticsSchemaTable.
        :type: str
        """

        self._table_name = table_name
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(AnalyticsSchemaTable, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, AnalyticsSchemaTable):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentConnectorConfiguration:

    swagger_types = {
    
        'applicable_for_transaction_processing': 'bool',
        'conditions': 'list[int]',
        'connector': 'int',
        'enabled_sales_channels': 'list[SalesChannel]',
        'enabled_space_views': 'list[int]',
        'id': 'int',
        'linked_space_id': 'int',
        'name': 'str',
        'payment_method_configuration': 'PaymentMethodConfiguration',
        'planned_purge_date': 'datetime',
        'priority': 'int',
        'processor_configuration': 'PaymentProcessorConfiguration',
        'state': 'CreationEntityState',
        'version': 'int',
    }

    attribute_map = {
        'applicable_for_transaction_processing': 'applicableForTransactionProcessing','conditions': 'conditions','connector': 'connector','enabled_sales_channels': 'enabledSalesChannels','enabled_space_views': 'enabledSpaceViews','id': 'id','linked_space_id': 'linkedSpaceId','name': 'name','payment_method_configuration': 'paymentMethodConfiguration','planned_purge_date': 'plannedPurgeDate','priority': 'priority','processor_configuration': 'processorConfiguration','state': 'state','version': 'version',
    }

    
    _applicable_for_transaction_processing = None
    _conditions = None
    _connector = None
    _enabled_sales_channels = None
    _enabled_space_views = None
    _id = None
    _linked_space_id = None
    _name = None
    _payment_method_configuration = None
    _planned_purge_date = None
    _priority = None
    _processor_configuration = None
    _state = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.applicable_for_transaction_processing = kwargs.get('applicable_for_transaction_processing', None)
        self.conditions = kwargs.get('conditions', None)
        self.connector = kwargs.get('connector', None)
        self.enabled_sales_channels = kwargs.get('enabled_sales_channels', None)
        self.enabled_space_views = kwargs.get('enabled_space_views', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.name = kwargs.get('name', None)
        self.payment_method_configuration = kwargs.get('payment_method_configuration', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.priority = kwargs.get('priority', None)
        self.processor_configuration = kwargs.get('processor_configuration', None)
        self.state = kwargs.get('state', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def applicable_for_transaction_processing(self):
        """Gets the applicable_for_transaction_processing of this PaymentConnectorConfiguration.

            This property indicates if the connector is currently used for processing transactions. In case either the payment method configuration or the processor configuration is not active the connector will not be used even though the connector state is active.

        :return: The applicable_for_transaction_processing of this PaymentConnectorConfiguration.
        :rtype: bool
        """
        return self._applicable_for_transaction_processing

    @applicable_for_transaction_processing.setter
    def applicable_for_transaction_processing(self, applicable_for_transaction_processing):
        """Sets the applicable_for_transaction_processing of this PaymentConnectorConfiguration.

            This property indicates if the connector is currently used for processing transactions. In case either the payment method configuration or the processor configuration is not active the connector will not be used even though the connector state is active.

        :param applicable_for_transaction_processing: The applicable_for_transaction_processing of this PaymentConnectorConfiguration.
        :type: bool
        """

        self._applicable_for_transaction_processing = applicable_for_transaction_processing
    
    @property
    def conditions(self):
        """Gets the conditions of this PaymentConnectorConfiguration.

            If a transaction meet all selected conditions the connector configuration will be used to process the transaction otherwise the next connector configuration in line will be chosen according to the priorities.

        :return: The conditions of this PaymentConnectorConfiguration.
        :rtype: list[int]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this PaymentConnectorConfiguration.

            If a transaction meet all selected conditions the connector configuration will be used to process the transaction otherwise the next connector configuration in line will be chosen according to the priorities.

        :param conditions: The conditions of this PaymentConnectorConfiguration.
        :type: list[int]
        """

        self._conditions = conditions
    
    @property
    def connector(self):
        """Gets the connector of this PaymentConnectorConfiguration.

            

        :return: The connector of this PaymentConnectorConfiguration.
        :rtype: int
        """
        return self._connector

    @connector.setter
    def connector(self, connector):
        """Sets the connector of this PaymentConnectorConfiguration.

            

        :param connector: The connector of this PaymentConnectorConfiguration.
        :type: int
        """

        self._connector = connector
    
    @property
    def enabled_sales_channels(self):
        """Gets the enabled_sales_channels of this PaymentConnectorConfiguration.

            Defines the sales channels the connector configuration is enabled for. In case the set is empty, the connector configuration is enabled for all sales channels.

        :return: The enabled_sales_channels of this PaymentConnectorConfiguration.
        :rtype: list[SalesChannel]
        """
        return self._enabled_sales_channels

    @enabled_sales_channels.setter
    def enabled_sales_channels(self, enabled_sales_channels):
        """Sets the enabled_sales_channels of this PaymentConnectorConfiguration.

            Defines the sales channels the connector configuration is enabled for. In case the set is empty, the connector configuration is enabled for all sales channels.

        :param enabled_sales_channels: The enabled_sales_channels of this PaymentConnectorConfiguration.
        :type: list[SalesChannel]
        """

        self._enabled_sales_channels = enabled_sales_channels
    
    @property
    def enabled_space_views(self):
        """Gets the enabled_space_views of this PaymentConnectorConfiguration.

            The connector configuration is only enabled for the selected space views. In case the set is empty the connector configuration is enabled for all space views.

        :return: The enabled_space_views of this PaymentConnectorConfiguration.
        :rtype: list[int]
        """
        return self._enabled_space_views

    @enabled_space_views.setter
    def enabled_space_views(self, enabled_space_views):
        """Sets the enabled_space_views of this PaymentConnectorConfiguration.

            The connector configuration is only enabled for the selected space views. In case the set is empty the connector configuration is enabled for all space views.

        :param enabled_space_views: The enabled_space_views of this PaymentConnectorConfiguration.
        :type: list[int]
        """

        self._enabled_space_views = enabled_space_views
    
    @property
    def id(self):
        """Gets the id of this PaymentConnectorConfiguration.

            A unique identifier for the object.

        :return: The id of this PaymentConnectorConfiguration.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentConnectorConfiguration.

            A unique identifier for the object.

        :param id: The id of this PaymentConnectorConfiguration.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this PaymentConnectorConfiguration.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this PaymentConnectorConfiguration.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this PaymentConnectorConfiguration.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this PaymentConnectorConfiguration.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def name(self):
        """Gets the name of this PaymentConnectorConfiguration.

            The connector configuration name is used internally to identify the configuration in administrative interfaces. For example it is used within search fields and hence it should be distinct and descriptive.

        :return: The name of this PaymentConnectorConfiguration.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PaymentConnectorConfiguration.

            The connector configuration name is used internally to identify the configuration in administrative interfaces. For example it is used within search fields and hence it should be distinct and descriptive.

        :param name: The name of this PaymentConnectorConfiguration.
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")

        self._name = name
    
    @property
    def payment_method_configuration(self):
        """Gets the payment_method_configuration of this PaymentConnectorConfiguration.

            

        :return: The payment_method_configuration of this PaymentConnectorConfiguration.
        :rtype: PaymentMethodConfiguration
        """
        return self._payment_method_configuration

    @payment_method_configuration.setter
    def payment_method_configuration(self, payment_method_configuration):
        """Sets the payment_method_configuration of this PaymentConnectorConfiguration.

            

        :param payment_method_configuration: The payment_method_configuration of this PaymentConnectorConfiguration.
        :type: PaymentMethodConfiguration
        """

        self._payment_method_configuration = payment_method_configuration
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this PaymentConnectorConfiguration.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this PaymentConnectorConfiguration.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this PaymentConnectorConfiguration.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this PaymentConnectorConfiguration.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def priority(self):
        """Gets the priority of this PaymentConnectorConfiguration.

            The priority will define the order of choice of the connector configurations. The lower the value, the higher the priority is going to be. This value can also be a negative number in case you are adding a new configuration that you want to have a high priority and you dont want to change the priority of all the other configurations.

        :return: The priority of this PaymentConnectorConfiguration.
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this PaymentConnectorConfiguration.

            The priority will define the order of choice of the connector configurations. The lower the value, the higher the priority is going to be. This value can also be a negative number in case you are adding a new configuration that you want to have a high priority and you dont want to change the priority of all the other configurations.

        :param priority: The priority of this PaymentConnectorConfiguration.
        :type: int
        """

        self._priority = priority
    
    @property
    def processor_configuration(self):
        """Gets the processor_configuration of this PaymentConnectorConfiguration.

            

        :return: The processor_configuration of this PaymentConnectorConfiguration.
        :rtype: PaymentProcessorConfiguration
        """
        return self._processor_configuration

    @processor_configuration.setter
    def processor_configuration(self, processor_configuration):
        """Sets the processor_configuration of this PaymentConnectorConfiguration.

            

        :param processor_configuration: The processor_configuration of this PaymentConnectorConfiguration.
        :type: PaymentProcessorConfiguration
        """

        self._processor_configuration = processor_configuration
    
    @property
    def state(self):
        """Gets the state of this PaymentConnectorConfiguration.

            The object's current state.

        :return: The state of this PaymentConnectorConfiguration.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this PaymentConnectorConfiguration.

            The object's current state.

        :param state: The state of this PaymentConnectorConfiguration.
        :type: CreationEntityState
        """

        self._state = state
    
    @property
    def version(self):
        """Gets the version of this PaymentConnectorConfiguration.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this PaymentConnectorConfiguration.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PaymentConnectorConfiguration.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this PaymentConnectorConfiguration.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentConnectorConfiguration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentConnectorConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum
from . import AbstractTransactionPending


class TransactionCreate(AbstractTransactionPending):

    swagger_types = {
    
        'auto_confirmation_enabled': 'bool',
        'charge_retry_enabled': 'bool',
        'customers_presence': 'CustomersPresence',
        'device_session_identifier': 'str',
        'emails_disabled': 'bool',
        'environment': 'Environment',
        'environment_selection_strategy': 'TransactionEnvironmentSelectionStrategy',
        'space_view_id': 'int',
    }

    attribute_map = {
        'auto_confirmation_enabled': 'autoConfirmationEnabled','charge_retry_enabled': 'chargeRetryEnabled','customers_presence': 'customersPresence','device_session_identifier': 'deviceSessionIdentifier','emails_disabled': 'emailsDisabled','environment': 'environment','environment_selection_strategy': 'environmentSelectionStrategy','space_view_id': 'spaceViewId',
    }

    
    _auto_confirmation_enabled = None
    _charge_retry_enabled = None
    _customers_presence = None
    _device_session_identifier = None
    _emails_disabled = None
    _environment = None
    _environment_selection_strategy = None
    _space_view_id = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.auto_confirmation_enabled = kwargs.get('auto_confirmation_enabled', None)
        self.charge_retry_enabled = kwargs.get('charge_retry_enabled', None)
        self.customers_presence = kwargs.get('customers_presence', None)
        self.device_session_identifier = kwargs.get('device_session_identifier', None)
        self.emails_disabled = kwargs.get('emails_disabled', None)
        self.environment = kwargs.get('environment', None)
        self.environment_selection_strategy = kwargs.get('environment_selection_strategy', None)
        self.space_view_id = kwargs.get('space_view_id', None)
        super().__init__(**kwargs)
        self.swagger_types.update(super().swagger_types)
        self.attribute_map.update(super().attribute_map)

    
    @property
    def auto_confirmation_enabled(self):
        """Gets the auto_confirmation_enabled of this TransactionCreate.

            When auto confirmation is enabled the transaction can be confirmed by the user and does not require an explicit confirmation through the web service API.

        :return: The auto_confirmation_enabled of this TransactionCreate.
        :rtype: bool
        """
        return self._auto_confirmation_enabled

    @auto_confirmation_enabled.setter
    def auto_confirmation_enabled(self, auto_confirmation_enabled):
        """Sets the auto_confirmation_enabled of this TransactionCreate.

            When auto confirmation is enabled the transaction can be confirmed by the user and does not require an explicit confirmation through the web service API.

        :param auto_confirmation_enabled: The auto_confirmation_enabled of this TransactionCreate.
        :type: bool
        """

        self._auto_confirmation_enabled = auto_confirmation_enabled
    
    @property
    def charge_retry_enabled(self):
        """Gets the charge_retry_enabled of this TransactionCreate.

            When the charging of the customer fails we can retry the charging. This implies that we redirect the user back to the payment page which allows the customer to retry. By default we will retry.

        :return: The charge_retry_enabled of this TransactionCreate.
        :rtype: bool
        """
        return self._charge_retry_enabled

    @charge_retry_enabled.setter
    def charge_retry_enabled(self, charge_retry_enabled):
        """Sets the charge_retry_enabled of this TransactionCreate.

            When the charging of the customer fails we can retry the charging. This implies that we redirect the user back to the payment page which allows the customer to retry. By default we will retry.

        :param charge_retry_enabled: The charge_retry_enabled of this TransactionCreate.
        :type: bool
        """

        self._charge_retry_enabled = charge_retry_enabled
    
    @property
    def customers_presence(self):
        """Gets the customers_presence of this TransactionCreate.

            The customer's presence indicates what kind of authentication method was finally used during authorization of the transaction. If no value is provided, 'Virtually Present' is used by default.

        :return: The customers_presence of this TransactionCreate.
        :rtype: CustomersPresence
        """
        return self._customers_presence

    @customers_presence.setter
    def customers_presence(self, customers_presence):
        """Sets the customers_presence of this TransactionCreate.

            The customer's presence indicates what kind of authentication method was finally used during authorization of the transaction. If no value is provided, 'Virtually Present' is used by default.

        :param customers_presence: The customers_presence of this TransactionCreate.
        :type: CustomersPresence
        """

        self._customers_presence = customers_presence
    
    @property
    def device_session_identifier(self):
        """Gets the device_session_identifier of this TransactionCreate.

            The device session identifier links the transaction with the session identifier provided in the URL of the device data JavaScript. This allows to link the transaction with the collected device data of the buyer.

        :return: The device_session_identifier of this TransactionCreate.
        :rtype: str
        """
        return self._device_session_identifier

    @device_session_identifier.setter
    def device_session_identifier(self, device_session_identifier):
        """Sets the device_session_identifier of this TransactionCreate.

            The device session identifier links the transaction with the session identifier provided in the URL of the device data JavaScript. This allows to link the transaction with the collected device data of the buyer.

        :param device_session_identifier: The device_session_identifier of this TransactionCreate.
        :type: str
        """
        if device_session_identifier is not None and len(device_session_identifier) > 40:
            raise ValueError("Invalid value for `device_session_identifier`, length must be less than or equal to `40`")
        if device_session_identifier is not None and len(device_session_identifier) < 10:
            raise ValueError("Invalid value for `device_session_identifier`, length must be greater than or equal to `10`")

        self._device_session_identifier = device_session_identifier
    
    @property
    def emails_disabled(self):
        """Gets the emails_disabled of this TransactionCreate.

            Flag indicating whether email sending is disabled for this particular transaction. Defaults to false.

        :return: The emails_disabled of this TransactionCreate.
        :rtype: bool
        """
        return self._emails_disabled

    @emails_disabled.setter
    def emails_disabled(self, emails_disabled):
        """Sets the emails_disabled of this TransactionCreate.

            Flag indicating whether email sending is disabled for this particular transaction. Defaults to false.

        :param emails_disabled: The emails_disabled of this TransactionCreate.
        :type: bool
        """

        self._emails_disabled = emails_disabled
    
    @property
    def environment(self):
        """Gets the environment of this TransactionCreate.

            

        :return: The environment of this TransactionCreate.
        :rtype: Environment
        """
        return self._environment

    @environment.setter
    def environment(self, environment):
        """Sets the environment of this TransactionCreate.

            

        :param environment: The environment of this TransactionCreate.
        :type: Environment
        """

        self._environment = environment
    
    @property
    def environment_selection_strategy(self):
        """Gets the environment_selection_strategy of this TransactionCreate.

            The environment selection strategy determines how the environment (test or production) for processing the transaction is selected.

        :return: The environment_selection_strategy of this TransactionCreate.
        :rtype: TransactionEnvironmentSelectionStrategy
        """
        return self._environment_selection_strategy

    @environment_selection_strategy.setter
    def environment_selection_strategy(self, environment_selection_strategy):
        """Sets the environment_selection_strategy of this TransactionCreate.

            The environment selection strategy determines how the environment (test or production) for processing the transaction is selected.

        :param environment_selection_strategy: The environment_selection_strategy of this TransactionCreate.
        :type: TransactionEnvironmentSelectionStrategy
        """

        self._environment_selection_strategy = environment_selection_strategy
    
    @property
    def space_view_id(self):
        """Gets the space_view_id of this TransactionCreate.

            

        :return: The space_view_id of this TransactionCreate.
        :rtype: int
        """
        return self._space_view_id

    @space_view_id.setter
    def space_view_id(self, space_view_id):
        """Sets the space_view_id of this TransactionCreate.

            

        :param space_view_id: The space_view_id of this TransactionCreate.
        :type: int
        """

        self._space_view_id = space_view_id
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(TransactionCreate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, TransactionCreate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class AbstractCustomerAddressActive:

    swagger_types = {
    
        'address': 'CustomerPostalAddressCreate',
        'address_type': 'CustomerAddressType',
    }

    attribute_map = {
        'address': 'address','address_type': 'addressType',
    }

    
    _address = None
    _address_type = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.address = kwargs.get('address', None)
        self.address_type = kwargs.get('address_type', None)
        

    
    @property
    def address(self):
        """Gets the address of this AbstractCustomerAddressActive.

            The actual postal address.

        :return: The address of this AbstractCustomerAddressActive.
        :rtype: CustomerPostalAddressCreate
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this AbstractCustomerAddressActive.

            The actual postal address.

        :param address: The address of this AbstractCustomerAddressActive.
        :type: CustomerPostalAddressCreate
        """

        self._address = address
    
    @property
    def address_type(self):
        """Gets the address_type of this AbstractCustomerAddressActive.

            Whether the address is for billing or shipping or both.

        :return: The address_type of this AbstractCustomerAddressActive.
        :rtype: CustomerAddressType
        """
        return self._address_type

    @address_type.setter
    def address_type(self, address_type):
        """Sets the address_type of this AbstractCustomerAddressActive.

            Whether the address is for billing or shipping or both.

        :param address_type: The address_type of this AbstractCustomerAddressActive.
        :type: CustomerAddressType
        """

        self._address_type = address_type
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(AbstractCustomerAddressActive, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, AbstractCustomerAddressActive):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum
from . import AbstractDebtCollectionCaseUpdate


class DebtCollectionCaseCreate(AbstractDebtCollectionCaseUpdate):

    swagger_types = {
    
        'collector_configuration': 'int',
        'external_id': 'str',
        'reference': 'str',
    }

    attribute_map = {
        'collector_configuration': 'collectorConfiguration','external_id': 'externalId','reference': 'reference',
    }

    
    _collector_configuration = None
    _external_id = None
    _reference = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.collector_configuration = kwargs.get('collector_configuration', None)
        self.external_id = kwargs.get('external_id')

        self.reference = kwargs.get('reference')

        super().__init__(**kwargs)
        self.swagger_types.update(super().swagger_types)
        self.attribute_map.update(super().attribute_map)

    
    @property
    def collector_configuration(self):
        """Gets the collector_configuration of this DebtCollectionCaseCreate.

            The collector configuration determines how the debt collection case is processed.

        :return: The collector_configuration of this DebtCollectionCaseCreate.
        :rtype: int
        """
        return self._collector_configuration

    @collector_configuration.setter
    def collector_configuration(self, collector_configuration):
        """Sets the collector_configuration of this DebtCollectionCaseCreate.

            The collector configuration determines how the debt collection case is processed.

        :param collector_configuration: The collector_configuration of this DebtCollectionCaseCreate.
        :type: int
        """

        self._collector_configuration = collector_configuration
    
    @property
    def external_id(self):
        """Gets the external_id of this DebtCollectionCaseCreate.

            A client generated nonce which identifies the entity to be created. Subsequent creation requests with the same external ID will not create new entities but return the initially created entity instead.

        :return: The external_id of this DebtCollectionCaseCreate.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this DebtCollectionCaseCreate.

            A client generated nonce which identifies the entity to be created. Subsequent creation requests with the same external ID will not create new entities but return the initially created entity instead.

        :param external_id: The external_id of this DebtCollectionCaseCreate.
        :type: str
        """
        if external_id is None:
            raise ValueError("Invalid value for `external_id`, must not be `None`")

        self._external_id = external_id
    
    @property
    def reference(self):
        """Gets the reference of this DebtCollectionCaseCreate.

            The case reference is used in the communication with the debtor. It should be unique and it should be linkable with the source of the debt collection case.

        :return: The reference of this DebtCollectionCaseCreate.
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this DebtCollectionCaseCreate.

            The case reference is used in the communication with the debtor. It should be unique and it should be linkable with the source of the debt collection case.

        :param reference: The reference of this DebtCollectionCaseCreate.
        :type: str
        """
        if reference is None:
            raise ValueError("Invalid value for `reference`, must not be `None`")

        self._reference = reference
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(DebtCollectionCaseCreate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, DebtCollectionCaseCreate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class SubscriptionProductVersionPending:

    swagger_types = {
    
        'id': 'int',
        'version': 'int',
        'billing_cycle': 'str',
        'comment': 'str',
        'default_currency': 'str',
        'enabled_currencies': 'list[str]',
        'minimal_number_of_periods': 'int',
        'name': 'dict(str, str)',
        'number_of_notice_periods': 'int',
        'product': 'int',
        'state': 'SubscriptionProductVersionState',
        'tax_calculation': 'TaxCalculation',
    }

    attribute_map = {
        'id': 'id','version': 'version','billing_cycle': 'billingCycle','comment': 'comment','default_currency': 'defaultCurrency','enabled_currencies': 'enabledCurrencies','minimal_number_of_periods': 'minimalNumberOfPeriods','name': 'name','number_of_notice_periods': 'numberOfNoticePeriods','product': 'product','state': 'state','tax_calculation': 'taxCalculation',
    }

    
    _id = None
    _version = None
    _billing_cycle = None
    _comment = None
    _default_currency = None
    _enabled_currencies = None
    _minimal_number_of_periods = None
    _name = None
    _number_of_notice_periods = None
    _product = None
    _state = None
    _tax_calculation = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.id = kwargs.get('id')

        self.version = kwargs.get('version')

        self.billing_cycle = kwargs.get('billing_cycle', None)
        self.comment = kwargs.get('comment', None)
        self.default_currency = kwargs.get('default_currency', None)
        self.enabled_currencies = kwargs.get('enabled_currencies', None)
        self.minimal_number_of_periods = kwargs.get('minimal_number_of_periods', None)
        self.name = kwargs.get('name', None)
        self.number_of_notice_periods = kwargs.get('number_of_notice_periods', None)
        self.product = kwargs.get('product', None)
        self.state = kwargs.get('state', None)
        self.tax_calculation = kwargs.get('tax_calculation', None)
        

    
    @property
    def id(self):
        """Gets the id of this SubscriptionProductVersionPending.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this SubscriptionProductVersionPending.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SubscriptionProductVersionPending.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this SubscriptionProductVersionPending.
        :type: int
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id
    
    @property
    def version(self):
        """Gets the version of this SubscriptionProductVersionPending.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this SubscriptionProductVersionPending.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this SubscriptionProductVersionPending.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this SubscriptionProductVersionPending.
        :type: int
        """
        if version is None:
            raise ValueError("Invalid value for `version`, must not be `None`")

        self._version = version
    
    @property
    def billing_cycle(self):
        """Gets the billing_cycle of this SubscriptionProductVersionPending.

            The billing cycle determines the rhythm with which the subscriber is billed. The charging may have different rhythm.

        :return: The billing_cycle of this SubscriptionProductVersionPending.
        :rtype: str
        """
        return self._billing_cycle

    @billing_cycle.setter
    def billing_cycle(self, billing_cycle):
        """Sets the billing_cycle of this SubscriptionProductVersionPending.

            The billing cycle determines the rhythm with which the subscriber is billed. The charging may have different rhythm.

        :param billing_cycle: The billing_cycle of this SubscriptionProductVersionPending.
        :type: str
        """

        self._billing_cycle = billing_cycle
    
    @property
    def comment(self):
        """Gets the comment of this SubscriptionProductVersionPending.

            The comment allows to provide a internal comment for the version. It helps to document why a product was changed. The comment is not disclosed to the subscriber.

        :return: The comment of this SubscriptionProductVersionPending.
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this SubscriptionProductVersionPending.

            The comment allows to provide a internal comment for the version. It helps to document why a product was changed. The comment is not disclosed to the subscriber.

        :param comment: The comment of this SubscriptionProductVersionPending.
        :type: str
        """

        self._comment = comment
    
    @property
    def default_currency(self):
        """Gets the default_currency of this SubscriptionProductVersionPending.

            The default currency has to be used in all fees.

        :return: The default_currency of this SubscriptionProductVersionPending.
        :rtype: str
        """
        return self._default_currency

    @default_currency.setter
    def default_currency(self, default_currency):
        """Sets the default_currency of this SubscriptionProductVersionPending.

            The default currency has to be used in all fees.

        :param default_currency: The default_currency of this SubscriptionProductVersionPending.
        :type: str
        """

        self._default_currency = default_currency
    
    @property
    def enabled_currencies(self):
        """Gets the enabled_currencies of this SubscriptionProductVersionPending.

            The currencies which are enabled can be selected to define component fees. Currencies which are not enabled cannot be used to define fees.

        :return: The enabled_currencies of this SubscriptionProductVersionPending.
        :rtype: list[str]
        """
        return self._enabled_currencies

    @enabled_currencies.setter
    def enabled_currencies(self, enabled_currencies):
        """Sets the enabled_currencies of this SubscriptionProductVersionPending.

            The currencies which are enabled can be selected to define component fees. Currencies which are not enabled cannot be used to define fees.

        :param enabled_currencies: The enabled_currencies of this SubscriptionProductVersionPending.
        :type: list[str]
        """

        self._enabled_currencies = enabled_currencies
    
    @property
    def minimal_number_of_periods(self):
        """Gets the minimal_number_of_periods of this SubscriptionProductVersionPending.

            The minimal number of periods determines how long the subscription has to run before the subscription can be terminated.

        :return: The minimal_number_of_periods of this SubscriptionProductVersionPending.
        :rtype: int
        """
        return self._minimal_number_of_periods

    @minimal_number_of_periods.setter
    def minimal_number_of_periods(self, minimal_number_of_periods):
        """Sets the minimal_number_of_periods of this SubscriptionProductVersionPending.

            The minimal number of periods determines how long the subscription has to run before the subscription can be terminated.

        :param minimal_number_of_periods: The minimal_number_of_periods of this SubscriptionProductVersionPending.
        :type: int
        """

        self._minimal_number_of_periods = minimal_number_of_periods
    
    @property
    def name(self):
        """Gets the name of this SubscriptionProductVersionPending.

            The product version name is the name of the product which is shown to the user for the version. When the visible product name should be changed for a particular product a new version has to be created which contains the new name of the product.

        :return: The name of this SubscriptionProductVersionPending.
        :rtype: dict(str, str)
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SubscriptionProductVersionPending.

            The product version name is the name of the product which is shown to the user for the version. When the visible product name should be changed for a particular product a new version has to be created which contains the new name of the product.

        :param name: The name of this SubscriptionProductVersionPending.
        :type: dict(str, str)
        """

        self._name = name
    
    @property
    def number_of_notice_periods(self):
        """Gets the number_of_notice_periods of this SubscriptionProductVersionPending.

            The number of notice periods determines the number of periods which need to be paid between the request to terminate the subscription and the final period.

        :return: The number_of_notice_periods of this SubscriptionProductVersionPending.
        :rtype: int
        """
        return self._number_of_notice_periods

    @number_of_notice_periods.setter
    def number_of_notice_periods(self, number_of_notice_periods):
        """Sets the number_of_notice_periods of this SubscriptionProductVersionPending.

            The number of notice periods determines the number of periods which need to be paid between the request to terminate the subscription and the final period.

        :param number_of_notice_periods: The number_of_notice_periods of this SubscriptionProductVersionPending.
        :type: int
        """

        self._number_of_notice_periods = number_of_notice_periods
    
    @property
    def product(self):
        """Gets the product of this SubscriptionProductVersionPending.

            Each product version is linked to a product.

        :return: The product of this SubscriptionProductVersionPending.
        :rtype: int
        """
        return self._product

    @product.setter
    def product(self, product):
        """Sets the product of this SubscriptionProductVersionPending.

            Each product version is linked to a product.

        :param product: The product of this SubscriptionProductVersionPending.
        :type: int
        """

        self._product = product
    
    @property
    def state(self):
        """Gets the state of this SubscriptionProductVersionPending.

            The object's current state.

        :return: The state of this SubscriptionProductVersionPending.
        :rtype: SubscriptionProductVersionState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this SubscriptionProductVersionPending.

            The object's current state.

        :param state: The state of this SubscriptionProductVersionPending.
        :type: SubscriptionProductVersionState
        """

        self._state = state
    
    @property
    def tax_calculation(self):
        """Gets the tax_calculation of this SubscriptionProductVersionPending.

            Strategy that is used for tax calculation in fees.

        :return: The tax_calculation of this SubscriptionProductVersionPending.
        :rtype: TaxCalculation
        """
        return self._tax_calculation

    @tax_calculation.setter
    def tax_calculation(self, tax_calculation):
        """Sets the tax_calculation of this SubscriptionProductVersionPending.

            Strategy that is used for tax calculation in fees.

        :param tax_calculation: The tax_calculation of this SubscriptionProductVersionPending.
        :type: TaxCalculation
        """

        self._tax_calculation = tax_calculation
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(SubscriptionProductVersionPending, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, SubscriptionProductVersionPending):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentAppProcessorCreationRequest:

    swagger_types = {
    
        'documentation_url': 'str',
        'external_id': 'str',
        'name': 'str',
        'production_mode_url': 'str',
        'svg_icon': 'str',
    }

    attribute_map = {
        'documentation_url': 'documentationUrl','external_id': 'externalId','name': 'name','production_mode_url': 'productionModeUrl','svg_icon': 'svgIcon',
    }

    
    _documentation_url = None
    _external_id = None
    _name = None
    _production_mode_url = None
    _svg_icon = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.documentation_url = kwargs.get('documentation_url')

        self.external_id = kwargs.get('external_id')

        self.name = kwargs.get('name')

        self.production_mode_url = kwargs.get('production_mode_url', None)
        self.svg_icon = kwargs.get('svg_icon')

        

    
    @property
    def documentation_url(self):
        """Gets the documentation_url of this PaymentAppProcessorCreationRequest.

            The documentation URL has to point to a description of how to configure and use the processor.

        :return: The documentation_url of this PaymentAppProcessorCreationRequest.
        :rtype: str
        """
        return self._documentation_url

    @documentation_url.setter
    def documentation_url(self, documentation_url):
        """Sets the documentation_url of this PaymentAppProcessorCreationRequest.

            The documentation URL has to point to a description of how to configure and use the processor.

        :param documentation_url: The documentation_url of this PaymentAppProcessorCreationRequest.
        :type: str
        """
        if documentation_url is None:
            raise ValueError("Invalid value for `documentation_url`, must not be `None`")

        self._documentation_url = documentation_url
    
    @property
    def external_id(self):
        """Gets the external_id of this PaymentAppProcessorCreationRequest.

            The external ID identifies the processor within the external system. It has to be unique per space and for any subsequent update the same ID must be sent.

        :return: The external_id of this PaymentAppProcessorCreationRequest.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this PaymentAppProcessorCreationRequest.

            The external ID identifies the processor within the external system. It has to be unique per space and for any subsequent update the same ID must be sent.

        :param external_id: The external_id of this PaymentAppProcessorCreationRequest.
        :type: str
        """
        if external_id is None:
            raise ValueError("Invalid value for `external_id`, must not be `None`")
        if external_id is not None and len(external_id) > 40:
            raise ValueError("Invalid value for `external_id`, length must be less than or equal to `40`")
        if external_id is not None and len(external_id) < 1:
            raise ValueError("Invalid value for `external_id`, length must be greater than or equal to `1`")

        self._external_id = external_id
    
    @property
    def name(self):
        """Gets the name of this PaymentAppProcessorCreationRequest.

            The name of the processor will be displayed within the user interfaces that the merchant is interacting with.

        :return: The name of this PaymentAppProcessorCreationRequest.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PaymentAppProcessorCreationRequest.

            The name of the processor will be displayed within the user interfaces that the merchant is interacting with.

        :param name: The name of this PaymentAppProcessorCreationRequest.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")
        if name is not None and len(name) > 100:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")

        self._name = name
    
    @property
    def production_mode_url(self):
        """Gets the production_mode_url of this PaymentAppProcessorCreationRequest.

            The production mode URL has to point to a site on which the merchant can set up the production mode for the processor.

        :return: The production_mode_url of this PaymentAppProcessorCreationRequest.
        :rtype: str
        """
        return self._production_mode_url

    @production_mode_url.setter
    def production_mode_url(self, production_mode_url):
        """Sets the production_mode_url of this PaymentAppProcessorCreationRequest.

            The production mode URL has to point to a site on which the merchant can set up the production mode for the processor.

        :param production_mode_url: The production_mode_url of this PaymentAppProcessorCreationRequest.
        :type: str
        """

        self._production_mode_url = production_mode_url
    
    @property
    def svg_icon(self):
        """Gets the svg_icon of this PaymentAppProcessorCreationRequest.

            The SVG icon will be displayed to the user to represent this processor.

        :return: The svg_icon of this PaymentAppProcessorCreationRequest.
        :rtype: str
        """
        return self._svg_icon

    @svg_icon.setter
    def svg_icon(self, svg_icon):
        """Sets the svg_icon of this PaymentAppProcessorCreationRequest.

            The SVG icon will be displayed to the user to represent this processor.

        :param svg_icon: The svg_icon of this PaymentAppProcessorCreationRequest.
        :type: str
        """
        if svg_icon is None:
            raise ValueError("Invalid value for `svg_icon`, must not be `None`")
        if svg_icon is not None and len(svg_icon) > 10000:
            raise ValueError("Invalid value for `svg_icon`, length must be less than or equal to `10000`")

        self._svg_icon = svg_icon
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentAppProcessorCreationRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentAppProcessorCreationRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class Account:

    swagger_types = {
    
        'active': 'bool',
        'active_or_restricted_active': 'bool',
        'created_by': 'int',
        'created_on': 'datetime',
        'deleted_by': 'int',
        'deleted_on': 'datetime',
        'id': 'int',
        'last_modified_date': 'datetime',
        'name': 'str',
        'parent_account': 'Account',
        'planned_purge_date': 'datetime',
        'restricted_active': 'bool',
        'scope': 'int',
        'state': 'AccountState',
        'subaccount_limit': 'int',
        'type': 'AccountType',
        'version': 'int',
    }

    attribute_map = {
        'active': 'active','active_or_restricted_active': 'activeOrRestrictedActive','created_by': 'createdBy','created_on': 'createdOn','deleted_by': 'deletedBy','deleted_on': 'deletedOn','id': 'id','last_modified_date': 'lastModifiedDate','name': 'name','parent_account': 'parentAccount','planned_purge_date': 'plannedPurgeDate','restricted_active': 'restrictedActive','scope': 'scope','state': 'state','subaccount_limit': 'subaccountLimit','type': 'type','version': 'version',
    }

    
    _active = None
    _active_or_restricted_active = None
    _created_by = None
    _created_on = None
    _deleted_by = None
    _deleted_on = None
    _id = None
    _last_modified_date = None
    _name = None
    _parent_account = None
    _planned_purge_date = None
    _restricted_active = None
    _scope = None
    _state = None
    _subaccount_limit = None
    _type = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.active = kwargs.get('active', None)
        self.active_or_restricted_active = kwargs.get('active_or_restricted_active', None)
        self.created_by = kwargs.get('created_by', None)
        self.created_on = kwargs.get('created_on', None)
        self.deleted_by = kwargs.get('deleted_by', None)
        self.deleted_on = kwargs.get('deleted_on', None)
        self.id = kwargs.get('id', None)
        self.last_modified_date = kwargs.get('last_modified_date', None)
        self.name = kwargs.get('name', None)
        self.parent_account = kwargs.get('parent_account', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.restricted_active = kwargs.get('restricted_active', None)
        self.scope = kwargs.get('scope', None)
        self.state = kwargs.get('state', None)
        self.subaccount_limit = kwargs.get('subaccount_limit', None)
        self.type = kwargs.get('type', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def active(self):
        """Gets the active of this Account.

            Whether this account and all its parent accounts are active.

        :return: The active of this Account.
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this Account.

            Whether this account and all its parent accounts are active.

        :param active: The active of this Account.
        :type: bool
        """

        self._active = active
    
    @property
    def active_or_restricted_active(self):
        """Gets the active_or_restricted_active of this Account.

            Whether this account and all its parent accounts are active or restricted active.

        :return: The active_or_restricted_active of this Account.
        :rtype: bool
        """
        return self._active_or_restricted_active

    @active_or_restricted_active.setter
    def active_or_restricted_active(self, active_or_restricted_active):
        """Sets the active_or_restricted_active of this Account.

            Whether this account and all its parent accounts are active or restricted active.

        :param active_or_restricted_active: The active_or_restricted_active of this Account.
        :type: bool
        """

        self._active_or_restricted_active = active_or_restricted_active
    
    @property
    def created_by(self):
        """Gets the created_by of this Account.

            The ID of the user the account was created by.

        :return: The created_by of this Account.
        :rtype: int
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this Account.

            The ID of the user the account was created by.

        :param created_by: The created_by of this Account.
        :type: int
        """

        self._created_by = created_by
    
    @property
    def created_on(self):
        """Gets the created_on of this Account.

            The date and time when the account was created.

        :return: The created_on of this Account.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this Account.

            The date and time when the account was created.

        :param created_on: The created_on of this Account.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def deleted_by(self):
        """Gets the deleted_by of this Account.

            The ID of a user the account was deleted by.

        :return: The deleted_by of this Account.
        :rtype: int
        """
        return self._deleted_by

    @deleted_by.setter
    def deleted_by(self, deleted_by):
        """Sets the deleted_by of this Account.

            The ID of a user the account was deleted by.

        :param deleted_by: The deleted_by of this Account.
        :type: int
        """

        self._deleted_by = deleted_by
    
    @property
    def deleted_on(self):
        """Gets the deleted_on of this Account.

            The date and time when the account was deleted.

        :return: The deleted_on of this Account.
        :rtype: datetime
        """
        return self._deleted_on

    @deleted_on.setter
    def deleted_on(self, deleted_on):
        """Sets the deleted_on of this Account.

            The date and time when the account was deleted.

        :param deleted_on: The deleted_on of this Account.
        :type: datetime
        """

        self._deleted_on = deleted_on
    
    @property
    def id(self):
        """Gets the id of this Account.

            A unique identifier for the object.

        :return: The id of this Account.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Account.

            A unique identifier for the object.

        :param id: The id of this Account.
        :type: int
        """

        self._id = id
    
    @property
    def last_modified_date(self):
        """Gets the last_modified_date of this Account.

            The date and time when the object was last modified.

        :return: The last_modified_date of this Account.
        :rtype: datetime
        """
        return self._last_modified_date

    @last_modified_date.setter
    def last_modified_date(self, last_modified_date):
        """Sets the last_modified_date of this Account.

            The date and time when the object was last modified.

        :param last_modified_date: The last_modified_date of this Account.
        :type: datetime
        """

        self._last_modified_date = last_modified_date
    
    @property
    def name(self):
        """Gets the name of this Account.

            The name used to identify the account.

        :return: The name of this Account.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Account.

            The name used to identify the account.

        :param name: The name of this Account.
        :type: str
        """
        if name is not None and len(name) > 200:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `200`")
        if name is not None and len(name) < 3:
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `3`")

        self._name = name
    
    @property
    def parent_account(self):
        """Gets the parent_account of this Account.

            The parent account responsible for administering this account.

        :return: The parent_account of this Account.
        :rtype: Account
        """
        return self._parent_account

    @parent_account.setter
    def parent_account(self, parent_account):
        """Sets the parent_account of this Account.

            The parent account responsible for administering this account.

        :param parent_account: The parent_account of this Account.
        :type: Account
        """

        self._parent_account = parent_account
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this Account.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this Account.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this Account.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this Account.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def restricted_active(self):
        """Gets the restricted_active of this Account.

            Whether this account and all its parent accounts are active or restricted active. There is at least one account that is restricted active.

        :return: The restricted_active of this Account.
        :rtype: bool
        """
        return self._restricted_active

    @restricted_active.setter
    def restricted_active(self, restricted_active):
        """Sets the restricted_active of this Account.

            Whether this account and all its parent accounts are active or restricted active. There is at least one account that is restricted active.

        :param restricted_active: The restricted_active of this Account.
        :type: bool
        """

        self._restricted_active = restricted_active
    
    @property
    def scope(self):
        """Gets the scope of this Account.

            The scope that the account belongs to.

        :return: The scope of this Account.
        :rtype: int
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this Account.

            The scope that the account belongs to.

        :param scope: The scope of this Account.
        :type: int
        """

        self._scope = scope
    
    @property
    def state(self):
        """Gets the state of this Account.

            The object's current state.

        :return: The state of this Account.
        :rtype: AccountState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Account.

            The object's current state.

        :param state: The state of this Account.
        :type: AccountState
        """

        self._state = state
    
    @property
    def subaccount_limit(self):
        """Gets the subaccount_limit of this Account.

            The number of sub-accounts that can be created within this account.

        :return: The subaccount_limit of this Account.
        :rtype: int
        """
        return self._subaccount_limit

    @subaccount_limit.setter
    def subaccount_limit(self, subaccount_limit):
        """Sets the subaccount_limit of this Account.

            The number of sub-accounts that can be created within this account.

        :param subaccount_limit: The subaccount_limit of this Account.
        :type: int
        """

        self._subaccount_limit = subaccount_limit
    
    @property
    def type(self):
        """Gets the type of this Account.

            The account's type which defines its role and capabilities.

        :return: The type of this Account.
        :rtype: AccountType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Account.

            The account's type which defines its role and capabilities.

        :param type: The type of this Account.
        :type: AccountType
        """

        self._type = type
    
    @property
    def version(self):
        """Gets the version of this Account.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this Account.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Account.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this Account.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(Account, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, Account):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class DebtCollectionCaseState(Enum):
    
    CREATE = "CREATE"
    PREPARING = "PREPARING"
    REVIEWING = "REVIEWING"
    PENDING = "PENDING"
    PROCESSING = "PROCESSING"
    CLOSED = "CLOSED"
    FAILED = "FAILED"




# coding: utf-8
import pprint
import six
from enum import Enum



class RefundCreate:

    swagger_types = {
    
        'amount': 'float',
        'completion': 'int',
        'external_id': 'str',
        'merchant_reference': 'str',
        'reductions': 'list[LineItemReductionCreate]',
        'transaction': 'int',
        'type': 'RefundType',
    }

    attribute_map = {
        'amount': 'amount','completion': 'completion','external_id': 'externalId','merchant_reference': 'merchantReference','reductions': 'reductions','transaction': 'transaction','type': 'type',
    }

    
    _amount = None
    _completion = None
    _external_id = None
    _merchant_reference = None
    _reductions = None
    _transaction = None
    _type = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.amount = kwargs.get('amount', None)
        self.completion = kwargs.get('completion', None)
        self.external_id = kwargs.get('external_id')

        self.merchant_reference = kwargs.get('merchant_reference', None)
        self.reductions = kwargs.get('reductions', None)
        self.transaction = kwargs.get('transaction', None)
        self.type = kwargs.get('type')

        

    
    @property
    def amount(self):
        """Gets the amount of this RefundCreate.

            

        :return: The amount of this RefundCreate.
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this RefundCreate.

            

        :param amount: The amount of this RefundCreate.
        :type: float
        """

        self._amount = amount
    
    @property
    def completion(self):
        """Gets the completion of this RefundCreate.

            

        :return: The completion of this RefundCreate.
        :rtype: int
        """
        return self._completion

    @completion.setter
    def completion(self, completion):
        """Sets the completion of this RefundCreate.

            

        :param completion: The completion of this RefundCreate.
        :type: int
        """

        self._completion = completion
    
    @property
    def external_id(self):
        """Gets the external_id of this RefundCreate.

            The external id helps to identify duplicate calls to the refund service. As such the external ID has to be unique per transaction.

        :return: The external_id of this RefundCreate.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this RefundCreate.

            The external id helps to identify duplicate calls to the refund service. As such the external ID has to be unique per transaction.

        :param external_id: The external_id of this RefundCreate.
        :type: str
        """
        if external_id is None:
            raise ValueError("Invalid value for `external_id`, must not be `None`")
        if external_id is not None and len(external_id) > 100:
            raise ValueError("Invalid value for `external_id`, length must be less than or equal to `100`")
        if external_id is not None and len(external_id) < 1:
            raise ValueError("Invalid value for `external_id`, length must be greater than or equal to `1`")

        self._external_id = external_id
    
    @property
    def merchant_reference(self):
        """Gets the merchant_reference of this RefundCreate.

            

        :return: The merchant_reference of this RefundCreate.
        :rtype: str
        """
        return self._merchant_reference

    @merchant_reference.setter
    def merchant_reference(self, merchant_reference):
        """Sets the merchant_reference of this RefundCreate.

            

        :param merchant_reference: The merchant_reference of this RefundCreate.
        :type: str
        """
        if merchant_reference is not None and len(merchant_reference) > 100:
            raise ValueError("Invalid value for `merchant_reference`, length must be less than or equal to `100`")

        self._merchant_reference = merchant_reference
    
    @property
    def reductions(self):
        """Gets the reductions of this RefundCreate.

            

        :return: The reductions of this RefundCreate.
        :rtype: list[LineItemReductionCreate]
        """
        return self._reductions

    @reductions.setter
    def reductions(self, reductions):
        """Sets the reductions of this RefundCreate.

            

        :param reductions: The reductions of this RefundCreate.
        :type: list[LineItemReductionCreate]
        """

        self._reductions = reductions
    
    @property
    def transaction(self):
        """Gets the transaction of this RefundCreate.

            

        :return: The transaction of this RefundCreate.
        :rtype: int
        """
        return self._transaction

    @transaction.setter
    def transaction(self, transaction):
        """Sets the transaction of this RefundCreate.

            

        :param transaction: The transaction of this RefundCreate.
        :type: int
        """

        self._transaction = transaction
    
    @property
    def type(self):
        """Gets the type of this RefundCreate.

            

        :return: The type of this RefundCreate.
        :rtype: RefundType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this RefundCreate.

            

        :param type: The type of this RefundCreate.
        :type: RefundType
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")

        self._type = type
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(RefundCreate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, RefundCreate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum
from . import User


class ApplicationUser(User):

    swagger_types = {
    
        'name': 'str',
        'primary_account': 'int',
        'request_limit': 'int',
    }

    attribute_map = {
        'name': 'name','primary_account': 'primaryAccount','request_limit': 'requestLimit',
    }

    
    _name = None
    _primary_account = None
    _request_limit = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.name = kwargs.get('name', None)
        self.primary_account = kwargs.get('primary_account', None)
        self.request_limit = kwargs.get('request_limit', None)
        super().__init__(**kwargs)
        self.swagger_types.update(super().swagger_types)
        self.attribute_map.update(super().attribute_map)

    
    @property
    def name(self):
        """Gets the name of this ApplicationUser.

            The name used to identify the application user.

        :return: The name of this ApplicationUser.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ApplicationUser.

            The name used to identify the application user.

        :param name: The name of this ApplicationUser.
        :type: str
        """
        if name is not None and len(name) > 256:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `256`")

        self._name = name
    
    @property
    def primary_account(self):
        """Gets the primary_account of this ApplicationUser.

            The primary account that the user belongs to.

        :return: The primary_account of this ApplicationUser.
        :rtype: int
        """
        return self._primary_account

    @primary_account.setter
    def primary_account(self, primary_account):
        """Sets the primary_account of this ApplicationUser.

            The primary account that the user belongs to.

        :param primary_account: The primary_account of this ApplicationUser.
        :type: int
        """

        self._primary_account = primary_account
    
    @property
    def request_limit(self):
        """Gets the request_limit of this ApplicationUser.

            The maximum number of API requests that are accepted every 2 minutes.

        :return: The request_limit of this ApplicationUser.
        :rtype: int
        """
        return self._request_limit

    @request_limit.setter
    def request_limit(self, request_limit):
        """Sets the request_limit of this ApplicationUser.

            The maximum number of API requests that are accepted every 2 minutes.

        :param request_limit: The request_limit of this ApplicationUser.
        :type: int
        """

        self._request_limit = request_limit
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ApplicationUser, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ApplicationUser):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum
from . import AbstractApplicationUserUpdate


class ApplicationUserCreate(AbstractApplicationUserUpdate):

    swagger_types = {
    
        'primary_account': 'int',
    }

    attribute_map = {
        'primary_account': 'primaryAccount',
    }

    
    _primary_account = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.primary_account = kwargs.get('primary_account')

        super().__init__(**kwargs)
        self.swagger_types.update(super().swagger_types)
        self.attribute_map.update(super().attribute_map)

    
    @property
    def primary_account(self):
        """Gets the primary_account of this ApplicationUserCreate.

            The primary account that the user belongs to.

        :return: The primary_account of this ApplicationUserCreate.
        :rtype: int
        """
        return self._primary_account

    @primary_account.setter
    def primary_account(self, primary_account):
        """Sets the primary_account of this ApplicationUserCreate.

            The primary account that the user belongs to.

        :param primary_account: The primary_account of this ApplicationUserCreate.
        :type: int
        """
        if primary_account is None:
            raise ValueError("Invalid value for `primary_account`, must not be `None`")

        self._primary_account = primary_account
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ApplicationUserCreate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ApplicationUserCreate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class TransactionLineItemVersionState(Enum):
    
    CREATE = "CREATE"
    SCHEDULED = "SCHEDULED"
    PENDING = "PENDING"
    SUCCESSFUL = "SUCCESSFUL"
    FAILED = "FAILED"

